@@ -4,6 +4,7 @@ import glob
 import inspect
 import itertools
 import functools
+import typing
 
 from ioc import provider
 from ioc import schema
@@ -64,14 +65,15 @@ def override(name, value):
     return provide(name, value, force=True)
 
 
-def load(dependencies, override=False):
+def load(dependencies, override=False, using: typing.Optional[provider.Provider] = None):
     s = schema.Parser(override=override).load(dependencies)
-    s.resolve(schema.Resolver(provider))
+    s.resolve(schema.Resolver(using or provider))
 
 
 def load_config(
     filenames: list = ['etc/ioc.conf', 'etc/ioc.conf.d/*'],
-    override: bool = True
+    override: bool = True,
+    using: typing.Optional[provider.Provider] = None
 ):
     """Configure dependencies from the given configuration files. The
     `filenames` parameter is a list of string containing the files to read
@@ -86,7 +88,7 @@ def load_config(
     if isinstance(filenames, str):
         filenames = [filenames]
     for filepath in itertools.chain(*[glob.glob(x) for x in filenames]):
-        load(etc.read(filepath), override=override)
+        load(etc.read(filepath), override=override, using=using)
 
 
 def is_satisfied(name: str) -> bool:
